Index: device/gamepad/gamepad_provider.h |
diff --git a/device/gamepad/gamepad_provider.h b/device/gamepad/gamepad_provider.h |
index 6dea63ac52744b022165d3f739307548277bc847..063e8a4bf433937b55c0ddded05a3066a918ccb4 100644 |
--- a/device/gamepad/gamepad_provider.h |
+++ b/device/gamepad/gamepad_provider.h |
@@ -51,10 +51,8 @@ class DEVICE_GAMEPAD_EXPORT GamepadProvider |
~GamepadProvider() override; |
- // Returns the shared memory handle of the gamepad data duplicated into the |
- // given process. |
- base::SharedMemoryHandle GetSharedMemoryHandleForProcess( |
- base::ProcessHandle renderer_process); |
+ // Returns a duplicate of the shared memory handle of the gamepad data. |
+ base::SharedMemoryHandle DuplicateSharedMemoryHandle(); |
// Returns a new mojo::ScopedSharedBufferHandle of the gamepad data. |
mojo::ScopedSharedBufferHandle GetSharedBufferHandle(); |